@@ -26,26 +26,24 @@ class DeleteSnapshotRepoRequest(RoaRequest):
 		RoaRequest.__init__(self, 'elasticsearch', '2017-06-13', 'DeleteSnapshotRepo','elasticsearch')
 		self.set_uri_pattern('/openapi/instances/[InstanceId]/snapshot-repos')
 		self.set_method('DELETE')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_InstanceId(self):
+	def get_InstanceId(self): # string
 		return self.get_path_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_path_param('InstanceId',InstanceId)
-
-	def get_clientToken(self):
+	def set_InstanceId(self, InstanceId):  # string
+		self.add_path_param('InstanceId', InstanceId)
+	def get_clientToken(self): # string
 		return self.get_query_params().get('clientToken')
 
-	def set_clientToken(self,clientToken):
-		self.add_query_param('clientToken',clientToken)
-
-	def get_repoPath(self):
+	def set_clientToken(self, clientToken):  # string
+		self.add_query_param('clientToken', clientToken)
+	def get_repoPath(self): # string
 		return self.get_query_params().get('repoPath')
 
-	def set_repoPath(self,repoPath):
-		self.add_query_param('repoPath',repoPath)
\ No newline at end of file
+	def set_repoPath(self, repoPath):  # string
+		self.add_query_param('repoPath', repoPath)
