@@ -26,7 +26,14 @@ class GetClusterDataInformationRequest(RoaRequest):
 		RoaRequest.__init__(self, 'elasticsearch', '2017-06-13', 'GetClusterDataInformation','elasticsearch')
 		self.set_uri_pattern('/openapi/cluster/data-information')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_body(self): # string
+		return self.get_body_params().get('body')
+
+	def set_body(self, body):  # string
+		self.add_body_params('body', body)
